@@ -28,7 +28,6 @@ comploglik2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,fixed
 
         other_nuis=as.numeric(nuisance[!sel])   ## or nuis parameters (nugget sill skew df)         
 
-
 ############################################
 #if(!type_cop) { # not copula models 
 
@@ -36,20 +35,23 @@ comploglik2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,fixed
             anisopar<-param[namesaniso]
             coords1=GeoAniso(coords, anisopars=anisopar)
           c1=c(t(coords1[colidx,]));c2=c(t(coords1[rowidx,]))
-
           result=dotCall64::.C64(as.character(fan),
          SIGNATURE = c("integer","double","double","double","double", "integer","integer","double","integer","double","double","double","double","integer","integer","integer","integer"),  
-                        corrmodel,c1,c2,data1, data2, n[colidx],n[rowidx],paramcorr,weigthed, res= dotCall64::numeric_dc(1),Mean[colidx], Mean[rowidx], other_nuis,local,GPU,type_cop,cond_pair,
-          INTENT =    c("r","r","r","r","r","r","r","r","r","w","r","r","r", "r","r","r","r"),
+                        corrmodel,c1,c2,data1, data2, n[colidx],n[rowidx],paramcorr,weigthed, res= dotCall64::numeric_dc(1),Mean[colidx], Mean[rowidx], other_nuis,local,GPU,
+                        type_cop,cond_pair,
+          INTENT =    c(rep("r",9),"w",rep("r",7)),
              PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)$res
+
+
         }
          else
          {
+            #print(fan)
                   
          result=dotCall64::.C64(as.character(fan),
          SIGNATURE = c("integer","double","double", "integer","integer","double","integer","double","double","double","double","integer","integer","integer","integer"),  
                         corrmodel,data1, data2, n[colidx],n[rowidx],paramcorr,weigthed, res= dotCall64::numeric_dc(1),Mean[colidx], Mean[rowidx], other_nuis,local,GPU,type_cop,cond_pair,
-          INTENT =    c("r","r","r","r","r","r","r","rw","r","r","r","r","r", "r","r"),
+          INTENT =    c(rep("r",7),"w",rep("r",7)),
              PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)$res
        }
 return(-result)
@@ -79,9 +81,8 @@ comploglik_biv2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,f
         result=dotCall64::.C64(as.character(fan),
           SIGNATURE = c("integer","double","double", "integer","double","integer","double","double","double","double","integer","integer"),  
                         corrmodel,data1, data2, n,paramcorr,weigthed, res=res,Mean[colidx],Mean[rowidx],other_nuis,local,GPU,
-          INTENT =    c("r","r","r","r","r","r","rw", "r", "r","r", "r","r"),
+          INTENT =    c(rep("r",6),"w", rep("r", 5)),
              PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)$res
-        
         return(-result)
       }
 
@@ -105,7 +106,6 @@ comploglik_biv2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,f
     namesaniso=c("angle","ratio")
 
    
-   
    if(length(n)==1) n=rep(n,dimat)
 ####################### conditional ##############################################
     if(all(model==1, likelihood==1,type==2)) fname <- 'Comp_Cond_Gauss'                          
